/***************************************************************************
 $RCSfile$
                             -------------------
    cvs         : $Id: editsummaryreport.h 365 2006-01-24 01:01:49Z aquamaniac $
    begin       : Mon Mar 01 2004
    copyright   : (C) 2004 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/


#ifndef QBANKMANAGER_EDIT_SUMMARYREPORT_H
#define QBANKMANAGER_EDIT_SUMMARYREPORT_H



#include "editsummaryreport.ui.h"
#include <gwenhywfar/db.h>


class QComboBox;
class KBanking;


class EditSummaryReport:public EditSummaryReportUi {
  Q_OBJECT
private:
  GWEN_DB_NODE *_dbProfile;

  void _profileToGui(GWEN_DB_NODE *dbProfile);
  void _guiToProfile(GWEN_DB_NODE *dbProfile);

public:
  EditSummaryReport(KBanking *kb,
                    GWEN_DB_NODE *dbProfile,
                    QWidget* parent=0,
                    const char* name=0,
                    bool modal=FALSE,
                    Qt::WFlags fl =0);
  ~EditSummaryReport();

public slots:
  void accept();

};




#endif //QBANKMANAGER_EDIT_SUMMARYREPORT_H

